using Microsoft.Extensions.Options;
using MongoDB.Driver;

namespace Todo.Persistence.Mongo;

public class MongoDbConnectionHandler
{
    private readonly IOptionsMonitor<MongoDbOptions> _optionsMonitor;

    public MongoDbConnectionHandler(IOptionsMonitor<MongoDbOptions> optionsMonitor)
    {
        _optionsMonitor = optionsMonitor;
    }

    public IMongoDatabase CreateDatabaseConnection()
    {
        var options = _optionsMonitor.CurrentValue;

        return CreateConnectionFromOptions(options);
    }

    private static IMongoDatabase CreateConnectionFromOptions(MongoDbOptions options)
    {
        var conn = new MongoClient(
            $"mongodb://{options.Username}:{options.Password}@{options.Host}:{options.Port}");
        var database = conn.GetDatabase(options.Database);

        return database;
    }
}